#include <stdint.h>
#include <endian.h>
#include <byteswap.h>

#include "macros.h"
#include "common.h"
#include "bo.h"

#if BYTE_ORDER == LITTLE_ENDIAN
#define u16_as_le(a)	(a)
#define u32_as_le(a)	(a)
#define u16_as_be(a)	bswap_16(a)
#define u32_as_be(a)	bswap_32(a)

#elif BYTE_ORDER == BIG_ENDIAN
#define u16_as_le(a)	bswap_16(a)
#define u32_as_le(a)	bswap_32(a)
#define u16_as_be(a)	(a)
#define u32_as_be(a)	(a)

#else
#error byte order not defined!
#endif

uint16_t adj_bo_u16(uint16_t datum, int byte_order)
{
	uint16_t res; 
      
	switch (byte_order) {
	case BO_LE:
		res = u16_as_le(datum);
		break;
	case BO_BE:
		res = u16_as_be(datum);
		break;
	case BO_NATIVE:
		res = datum;
		break;
	}    

	return res; 
}
 
uint32_t adj_bo_u32(uint32_t datum, int byte_order)
{
	uint32_t res; 
      
	switch (byte_order) {
	case BO_LE:
		res = u32_as_le(datum);
		break;
	case BO_BE:
		res = u32_as_be(datum);
		break;
	case BO_NATIVE:
		res = datum;
		break;
	}

	return res; 
}

